/**
 * Copyright (c) 2009-2010, Arnoud Philip
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package com.dexels.blog;

import java.awt.*;
import java.util.Calendar;
import java.util.Date;

import javax.imageio.ImageIO;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.table.*;

import com.sun.java.swing.plaf.nimbus.NimbusLookAndFeel;

public class DemoFrame extends JFrame {
	PeelPanel peelContainer = new PeelPanel();

	public DemoFrame() {
		System.err.println(getClass().getClassLoader().getResource("com/dexels/blog/Pluto.png"));
		getContentPane().add(peelContainer, BorderLayout.CENTER);
		setupDemoContent();
		setSize(800, 600);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setTitle("Java Peel effect, by Arnoud Philip. 2010");
		setVisible(true);
	}

	private final void setupDemoContent() {
		try {
			JPanel pageOne = new JPanel();
			JPanel swingPanel = new JPanel();
			buildSwingPanel(swingPanel);
			JPanel pageThree = new JPanel();

			pageOne.setBackground(Color.white);
			pageThree.setBackground(Color.gray);

			JLabel imageLabel = new JLabel();
			imageLabel.setIcon(new ImageIcon(getClass().getClassLoader().getResource("com/dexels/blog/java_duke.png")));
			JLabel imageLabel2 = new JLabel();
			imageLabel2.setIcon(new ImageIcon(getClass().getClassLoader().getResource("com/dexels/blog/pebbles.jpg")));
			pageOne.setLayout(new BorderLayout());
			pageOne.add(imageLabel, BorderLayout.WEST);
			JLabel stack = new JLabel("You can stack multiple containers");
			pageOne.add(stack, BorderLayout.CENTER);
			pageThree.setLayout(new BorderLayout());
			pageThree.add(imageLabel2, BorderLayout.CENTER);

			peelContainer.setBacksideImage(ImageIO.read(getClass().getClassLoader().getResource("com/dexels/blog/money.jpg")));
			peelContainer.addComponent(pageOne);
			peelContainer.addComponent(pageThree);
			peelContainer.addComponent(swingPanel);
		} catch (Exception e) {

		}
	}

	private final void buildSwingPanel(JPanel p) {
		p.setLayout(new GridBagLayout());

		JTabbedPane tabs = new JTabbedPane();
		JScrollPane tabOne = new JScrollPane();
		JPanel tabTwo = new JPanel();

		JPanel companyPanel = new JPanel();
		companyPanel.setLayout(new GridBagLayout());
		JLabel labelOne = new JLabel("Company name");
		JLabel labelTwo = new JLabel("Company location");
		JTextField tfOne = new JTextField("Dog ear interfaces ltd.");
		JTextField tfTwo = new JTextField("Any corner");
		JLabel logoLabel = new JLabel();
		logoLabel.setIcon(new ImageIcon(getClass().getClassLoader().getResource("com/dexels/blog/Pluto.png")));

		TitledBorder companyBorder = BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(), "Company information");
		companyPanel.setBorder(companyBorder);
		companyPanel.add(labelOne, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(2, 2, 2, 2), 100, 0));
		companyPanel.add(labelTwo, new GridBagConstraints(0, 1, 1, 1, 0.0, 1.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(2, 2, 2, 2), 100, 0));
		companyPanel.add(tfOne, new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(2, 2, 2, 2), 0, 0));
		companyPanel.add(tfTwo, new GridBagConstraints(1, 1, 1, 1, 1.0, 1.0, GridBagConstraints.NORTHWEST, GridBagConstraints.HORIZONTAL, new Insets(2, 2, 2, 2), 0, 0));
		companyPanel.add(logoLabel, new GridBagConstraints(2, 0, 1, 2, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.BOTH, new Insets(2, 2, 2, 2), 0, 0));

		JTextArea text = new JTextArea();
		tabOne.getViewport().add(text);
		text.setText("Mouse the mousepointer over one of the corners of this frame");

		p.add(companyPanel, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, GridBagConstraints.NORTH, GridBagConstraints.HORIZONTAL, new Insets(2, 2, 2, 2), 0, 0));
		p.add(tabs, new GridBagConstraints(0, 1, 1, 1, 1.0, 1.0, GridBagConstraints.NORTH, GridBagConstraints.BOTH, new Insets(2, 2, 2, 2), 0, 0));

		tabs.addTab("Some data", tabOne);
		tabs.addTab("Some other data", tabTwo);

	}

	public static void main(String[] args) {
		try {
			JFrame.setDefaultLookAndFeelDecorated(true);
			UIManager.setLookAndFeel(new NimbusLookAndFeel());
		} catch (Exception e) {
			e.printStackTrace();
		}
		new DemoFrame();
	}	
}
